summaryrefslogtreecommitdiffstats
path: root/content/shell/android/java/src
diff options
context:
space:
mode:
authoryfriedman@chromium.org <yfriedman@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-04-24 00:01:45 +0000
committeryfriedman@chromium.org <yfriedman@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-04-24 00:01:45 +0000
commite524cb7472b0c30b3bb63d48b6c112b61467dff9 (patch)
tree099a53cb8eb707d0b1a5155177976d286be3c576 /content/shell/android/java/src
parent21bb77b0b200d156cfcdb5ee78fe98ec1fffc7d6 (diff)
downloadchromium_src-e524cb7472b0c30b3bb63d48b6c112b61467dff9.zip
chromium_src-e524cb7472b0c30b3bb63d48b6c112b61467dff9.tar.gz
chromium_src-e524cb7472b0c30b3bb63d48b6c112b61467dff9.tar.bz2
ContentView->ContentViewCore.getContainerView in content/ tests
Some spillover into chrome-layer tests too because of change to DOMUtils interface. Many places that don't need ContentView proper and just need the View managed by ContentViewCore. BUG=360664 Review URL: https://codereview.chromium.org/246233009 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@265778 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'content/shell/android/java/src')
-rw-r--r--content/shell/android/java/src/org/chromium/content_shell/Shell.java5
1 files changed, 3 insertions, 2 deletions
diff --git a/content/shell/android/java/src/org/chromium/content_shell/Shell.java b/content/shell/android/java/src/org/chromium/content_shell/Shell.java
index efe1749..99caca8 100644
--- a/content/shell/android/java/src/org/chromium/content_shell/Shell.java
+++ b/content/shell/android/java/src/org/chromium/content_shell/Shell.java
@@ -10,6 +10,7 @@ import android.text.TextUtils;
import android.util.AttributeSet;
import android.view.KeyEvent;
import android.view.View;
+import android.view.ViewGroup;
import android.view.inputmethod.EditorInfo;
import android.view.inputmethod.InputMethodManager;
import android.widget.EditText;
@@ -266,9 +267,9 @@ public class Shell extends LinearLayout {
}
/**
* @return The {@link ContentView} currently shown by this Shell.
*/
- public ContentView getContentView() {
+ public ViewGroup getContentView() {
return mContentView;
}
@@ -266,9 +267,9 @@ public class Shell extends LinearLayout {
}
/**
- * @return The {@link ContentView} currently shown by this Shell.
+ * @return The {@link ViewGroup} currently shown by this Shell.
*/